Task

Struct Task 

pub struct Task<Args> {
    pub args: Args,
    /* private fields */
}
Represents a task which will be executed Should be considered a single unit of work

Fields

args: Args

The argument task part

Implementations

Source

impl<Args> Task<Args>

pub fn new(args: Args) -> Self

Creates a new task given some args

Used to easily create a ready task. Please prefer to use TaskBuilder if you need to modify ExecutionContext

pub fn ctx(&self) -> &Arc<ExecutionContext>

Returns the execution context associated with the task.

Source

impl<Args> Task<Args>

pub fn take(self) -> (Args, Arc<ExecutionContext>)

Take the task into its parts

pub async fn extract<T: FromRequest<Self>>(&self) -> Result<T, T::Error>

Extract a value of type T from the task’s context

Uses FromRequest trait to extract the value.

pub fn map_args<F, NewArgs>(self, f: F) -> Task<NewArgs>
where F: FnOnce(Args) -> NewArgs,

Maps the args field using the provided function, consuming the task.

pub fn try_map_args<F, NewArgs, Err>(self, f: F) -> Result<Task<NewArgs>, Err>
where F: FnOnce(Args) -> Result<NewArgs, Err>,

Maps the args field using the provided function, consuming the task.

pub fn map_context<F>(self, f: F) -> Self

Maps the execution_context using the provided function, consuming the task

pub fn into_builder(self) -> TaskBuilder<Args>

Converts the task into a TaskBuilder

pub fn inject_data<D>(&mut self, data: D) -> Option<D>
where D: Send + Clone + Sync + 'static,

Inject data into the execution context via Arc::make_mut

If an extension of this type already existed, it will be returned.

pub fn inject_metadata<M>(&mut self, value: &M) -> Result<(), M::Error>
where M: Metadata,

Inject metadata into the execution context via Arc::make_mut

Methods from Deref<Target = ExecutionContext>

pub fn task_id(&self) -> Option<&TaskId>

Returns the task’s ID, if one has been allocated.

pub fn data(&self) -> &Extensions

Returns the extensions associated with the task.

pub fn attempt(&self) -> usize

Returns the number of attempts made to execute the task.

pub fn raw_attempt(&self) -> &Attempt

Get the atomic attempt

pub fn status(&self) -> Status

Returns the current status of the task.

pub fn raw_status(&self) -> &AtomicStatus

Get the atomic status

pub fn run_at(&self) -> Option<u64>

Returns the time at which the task is scheduled to run.

Returns None if no run time has been specified.

pub fn done_at(&self) -> Option<u64>

Returns the time at which the task was completed.

Returns None if the task has not been completed.

pub fn lock_at(&self) -> Option<u64>

Returns the time at which the task was locked.

Returns None if the task is not locked.

pub fn lock_by(&self) -> Option<&str>

Returns the identifier of the worker or process currently holding the lock on this task.

Returns None if the task is not currently locked.

pub fn idempotency_key(&self) -> Option<&str>

Returns the idempotency key associated with the task.

Returns None if no idempotency key has been specified.

pub fn metadata(&self) -> &MetadataStore

Returns the metadata associated with the task.

pub fn max_attempts(&self) -> Option<usize>

Returns the maximum number of attempts allowed for the task.

Returns None if no maximum has been specified.

pub fn priority(&self) -> Option<usize>

Returns the priority of the task.

Returns None if no priority has been specified.

pub fn queue(&self) -> Option<&Queue>

Returns the queue to which the task belongs.

Returns None if the task is not associated with a queue.

pub fn runs(&self) -> &[Run]

Returns the runs recorded for this task.