TaskId

Enum TaskId 

#[non_exhaustive]
pub enum TaskId { Int(u64), String(String), Uuid(Uuid), Ulid(Ulid), }
A wrapper type that defines a task id.

Supports a fixed set of common identifier representations. Uuid and Ulid variants are only available when the corresponding crate features are enabled.

Variants (Non-exhaustive)

This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.


Int(u64)

An integer-based id



String(String)

A string-based id



Uuid(Uuid)

Available on crate feature uuid only.

A UUID-based id



Ulid(Ulid)

Available on crate feature ulid only.

A ULID-based id

Implementations

Source

impl TaskId

pub fn from_int(id: u64) -> Self

Construct a TaskId from an integer.

pub fn from_string(id: impl Into<String>) -> Self

Construct a TaskId from a string.

pub fn from_uuid(id: Uuid) -> Self

Available on crate feature uuid only.

Construct a TaskId from a UUID.

pub fn from_ulid(id: Ulid) -> Self

Available on crate feature ulid only.

Construct a TaskId from a ULID.

pub fn as_int(&self) -> Option<u64>

Returns the inner value as an integer, if this is an Int variant.

pub fn as_string(&self) -> Option<&str>

Returns the inner value as a string slice, if this is a String variant.

pub fn as_uuid(&self) -> Option<Uuid>

Available on crate feature uuid only.

Returns the inner value as a Uuid, if this is a Uuid variant.

pub fn as_ulid(&self) -> Option<Ulid>

Available on crate feature ulid only.

Returns the inner value as a Ulid, if this is a Ulid variant.

Source

impl TaskId

pub fn to_uuid(&self) -> Uuid

Available on crate feature uuid only.

Generates a deterministic uuid based on the task id.