Trait apalis_core::MessageDecodable[][src]

pub trait MessageDecodable where
    Self: Sized
{ fn decode_message(value: &Vec<u8>) -> Result<Self, &'static str>; }
Message objects that can be reconstructed from the data stored in Storage.

Implemented for all Deserialize objects by default by relying on Msgpack decoding.

Required methods

fn decode_message(value: &Vec<u8>) -> Result<Self, &'static str>[src]

Decode the given Redis value into a message

In the default implementation, the string value is decoded by assuming it was encoded through the Msgpack encoding.

Loading content...

Implementors

impl<T> MessageDecodable for T where
    T: DeserializeOwned
[src]

fn decode_message(value: &Vec<u8>) -> Result<T, &'static str>[src]

Loading content...