pub struct Task<Args> {
pub args: Args,
/* private fields */
}Expand description
Represents a task which will be executed Should be considered a single unit of work
Fields
args: ArgsThe argument task part
Implementations
Sourceimpl<Args> Task<Args>
impl<Args> Task<Args>
Sourcepub fn new(args: Args) -> Self
pub fn new(args: Args) -> Self
Creates a new task given some args
Used to easily create a ready task.
Please prefer to use TaskBuilder if you need to modify ExecutionContext
Sourcepub fn ctx(&self) -> &Arc<ExecutionContext> ⓘ
pub fn ctx(&self) -> &Arc<ExecutionContext> ⓘ
Returns the execution context associated with the task.
Sourceimpl<Args> Task<Args>
impl<Args> Task<Args>
Sourcepub fn take(self) -> (Args, Arc<ExecutionContext>)
pub fn take(self) -> (Args, Arc<ExecutionContext>)
Take the task into its parts
Sourcepub async fn extract<T: FromRequest<Self>>(&self) -> Result<T, T::Error>
pub async fn extract<T: FromRequest<Self>>(&self) -> Result<T, T::Error>
Extract a value of type T from the task’s context
Uses FromRequest trait to extract the value.
Sourcepub fn map_args<F, NewArgs>(self, f: F) -> Task<NewArgs>where
F: FnOnce(Args) -> NewArgs,
pub fn map_args<F, NewArgs>(self, f: F) -> Task<NewArgs>where
F: FnOnce(Args) -> NewArgs,
Maps the args field using the provided function, consuming the task.
Sourcepub fn try_map_args<F, NewArgs, Err>(self, f: F) -> Result<Task<NewArgs>, Err>
pub fn try_map_args<F, NewArgs, Err>(self, f: F) -> Result<Task<NewArgs>, Err>
Maps the args field using the provided function, consuming the task.
Sourcepub fn map_context<F>(self, f: F) -> Self
pub fn map_context<F>(self, f: F) -> Self
Maps the execution_context using the provided function, consuming the task
Sourcepub fn into_builder(self) -> TaskBuilder<Args>
pub fn into_builder(self) -> TaskBuilder<Args>
Converts the task into a TaskBuilder
Sourcepub fn inject_data<D>(&mut self, data: D) -> Option<D>
pub fn inject_data<D>(&mut self, data: D) -> Option<D>
Inject data into the execution context via Arc::make_mut
If an extension of this type already existed, it will be returned.
Sourcepub fn inject_metadata<M>(&mut self, value: &M) -> Result<(), M::Error>where
M: Metadata,
pub fn inject_metadata<M>(&mut self, value: &M) -> Result<(), M::Error>where
M: Metadata,
Inject metadata into the execution context via Arc::make_mut
Methods from Deref<Target = ExecutionContext>
Sourcepub fn data(&self) -> &Extensions
pub fn data(&self) -> &Extensions
Returns the extensions associated with the task.
Sourcepub fn raw_attempt(&self) -> &Attempt
pub fn raw_attempt(&self) -> &Attempt
Get the atomic attempt
Sourcepub fn raw_status(&self) -> &AtomicStatus
pub fn raw_status(&self) -> &AtomicStatus
Get the atomic status
Sourcepub fn run_at(&self) -> Option<u64>
pub fn run_at(&self) -> Option<u64>
Returns the time at which the task is scheduled to run.
Returns None if no run time has been specified.
Sourcepub fn done_at(&self) -> Option<u64>
pub fn done_at(&self) -> Option<u64>
Returns the time at which the task was completed.
Returns None if the task has not been completed.
Sourcepub fn lock_at(&self) -> Option<u64>
pub fn lock_at(&self) -> Option<u64>
Returns the time at which the task was locked.
Returns None if the task is not locked.
Sourcepub fn lock_by(&self) -> Option<&str>
pub fn lock_by(&self) -> Option<&str>
Returns the identifier of the worker or process currently holding the lock on this task.
Returns None if the task is not currently locked.
Sourcepub fn idempotency_key(&self) -> Option<&str>
pub fn idempotency_key(&self) -> Option<&str>
Returns the idempotency key associated with the task.
Returns None if no idempotency key has been specified.
Sourcepub fn metadata(&self) -> &MetadataStore
pub fn metadata(&self) -> &MetadataStore
Returns the metadata associated with the task.
Sourcepub fn max_attempts(&self) -> Option<usize>
pub fn max_attempts(&self) -> Option<usize>
Returns the maximum number of attempts allowed for the task.
Returns None if no maximum has been specified.
Sourcepub fn priority(&self) -> Option<usize>
pub fn priority(&self) -> Option<usize>
Returns the priority of the task.
Returns None if no priority has been specified.