#[non_exhaustive]pub enum TaskId {
Int(u64),
String(String),
Uuid(Uuid),
Ulid(Ulid),
}Expand description
A wrapper type that defines a task id.
Supports a fixed set of common identifier representations. Uuid and
Ulid variants are only available when the corresponding crate features
are enabled.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
Int(u64)
An integer-based id
String(String)
A string-based id
Uuid(Uuid)
Available on crate feature
uuid only.A UUID-based id
Ulid(Ulid)
Available on crate feature
ulid only.A ULID-based id
Implementations
Sourceimpl TaskId
impl TaskId
Sourcepub fn from_string(id: impl Into<String>) -> Self
pub fn from_string(id: impl Into<String>) -> Self
Construct a TaskId from a string.
Sourcepub fn from_uuid(id: Uuid) -> Self
Available on crate feature uuid only.
pub fn from_uuid(id: Uuid) -> Self
uuid only.Construct a TaskId from a UUID.
Sourcepub fn from_ulid(id: Ulid) -> Self
Available on crate feature ulid only.
pub fn from_ulid(id: Ulid) -> Self
ulid only.Construct a TaskId from a ULID.
Sourcepub fn as_int(&self) -> Option<u64>
pub fn as_int(&self) -> Option<u64>
Returns the inner value as an integer, if this is an Int variant.
Sourcepub fn as_string(&self) -> Option<&str>
pub fn as_string(&self) -> Option<&str>
Returns the inner value as a string slice, if this is a String variant.