pub struct LifecycleService<S> { /* private fields */ }Expand description
A service that tracks the lifecycle of a task.
LifecycleService registers tasks with the worker before processing and
wraps the underlying service future in a LifecycleFuture to track task
state and completion.